==> aroundme_0_6_0.zip: aroundme_0_6_0/aroundme/language/1/barnraiser_01/arrays/arr_user.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------
// Tom Calthrop - 6th December 2004 (tom@barnraiser.org)



// USER STATUS -------------------------------------------------
$lang['arr_user_status'][1] = 							"inactive";
$lang['arr_user_status'][2] = 							"hold";
$lang['arr_user_status'][3] = 							"pending";
$lang['arr_user_status'][4] = 							"active";


// USER STATISTICS -------------------------------------------------
$lang['arr_user_statistic_type_id'][1] = 			"total logins";
$lang['arr_user_statistic_type_id'][2] = 			"total blogs";
$lang['arr_user_statistic_type_id'][3] = 			"total shouts";
$lang['arr_user_statistic_type_id'][4] = 			"total polls";
$lang['arr_user_statistic_type_id'][5] = 			"total wiki pages";
$lang['arr_user_statistic_type_id'][6] = 			"total discussions";
$lang['arr_user_statistic_type_id'][7] = 			"total comments";
$lang['arr_user_statistic_type_id'][8] = 			"total votes";
$lang['arr_user_statistic_type_id'][9] = 			"total schedule items";


// SOCIAL NETWORK -------------------------------------------------
$lang['sn']['degree'][1] = 							"friends";
$lang['sn']['degree'][2] = 							"two degrees away";
$lang['sn']['degree'][3] = 							"three degrees away";
$lang['sn']['degree'][4] = 							"four degrees away";

$lang['sn']['degree_desc'][1] = 					"your friends and colleagues";
$lang['sn']['degree_desc'][2] = 					"Your acquaintances (friends-of-friends); each is connected to one of your friends";
$lang['sn']['degree_desc'][3] = 					"People you can reach through a friend and one of their friends";
$lang['sn']['degree_desc'][4] = 					"People you hardly know";

// USER ONLINE STATUS ---------------------------------------------
$lang['arr_user_online_status'][1] = 				"online";
$lang['arr_user_online_status'][2] = 				"idle";
$lang['arr_user_online_status'][3] = 				"sleeping";
$lang['arr_user_online_status'][4] = 				"offline";


// USER ACTIVITY TYPE ---------------------------------------------
$lang['user']['arr_activity_type'][1] = 			"gig";
$lang['user']['arr_activity_type'][2] = 			"party";
$lang['user']['arr_activity_type'][3] = 			"gathering";

?>

==> aroundme_0_6_4.zip: aroundme_0_6_4/aroundme/language/1/barnraiser_01/arrays/arr_user.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------
// Tom Calthrop - 6th December 2004 (tom@barnraiser.org)



// USER STATUS -------------------------------------------------
$lang['arr_user_status'][1] = 							"inactive";
$lang['arr_user_status'][2] = 							"hold";
$lang['arr_user_status'][3] = 							"pending";
$lang['arr_user_status'][4] = 							"active";


// USER STATISTICS -------------------------------------------------
$lang['arr_user_statistic_type_id'][1] = 			"total logins";
$lang['arr_user_statistic_type_id'][2] = 			"total blogs";
$lang['arr_user_statistic_type_id'][3] = 			"total shouts";
$lang['arr_user_statistic_type_id'][4] = 			"total polls";
$lang['arr_user_statistic_type_id'][5] = 			"total wiki pages";
$lang['arr_user_statistic_type_id'][6] = 			"total discussions";
$lang['arr_user_statistic_type_id'][7] = 			"total comments";
$lang['arr_user_statistic_type_id'][8] = 			"total votes";
$lang['arr_user_statistic_type_id'][9] = 			"total schedule items";


// SOCIAL NETWORK -------------------------------------------------
$lang['sn']['degree'][1] = 							"one degree away";
$lang['sn']['degree'][2] = 							"two degrees away";
$lang['sn']['degree'][3] = 							"three degrees away";
$lang['sn']['degree'][4] = 							"four degrees away";

$lang['sn']['degree_desc'][1] = 					"your friends and colleagues";
$lang['sn']['degree_desc'][2] = 					"Your acquaintances (friends-of-friends); each is connected to one of your friends";
$lang['sn']['degree_desc'][3] = 					"People you can reach through a friend and one of their friends";
$lang['sn']['degree_desc'][4] = 					"People you hardly know";

// USER ONLINE STATUS ---------------------------------------------
$lang['arr_user_online_status'][1] = 				"online";
$lang['arr_user_online_status'][2] = 				"idle";
$lang['arr_user_online_status'][3] = 				"sleeping";
$lang['arr_user_online_status'][4] = 				"offline";


// USER ACTIVITY TYPE ---------------------------------------------
$lang['user']['arr_activity_type'][1] = 			"gig";
$lang['user']['arr_activity_type'][2] = 			"party";
$lang['user']['arr_activity_type'][3] = 			"gathering";

?>
